@@ -38,7 +38,7 @@ pub fn run(mut conf: Config) -> ViuResult {
         }
         std::process::exit(0);
     })
-    .map_err(|_| Error::new(ErrorKind::Other, "Could not setup Ctrl-C handler."))?;
+    .map_err(|_| Error::other("Could not setup Ctrl-C handler."))?;
 
     //TODO: handle multiple files
     //read stdin if only one parameter is passed and it is "-"
@@ -69,9 +69,9 @@ fn view_passed_files(conf: &mut Config, (tx, rx): TxRx) -> ViuResult {
     for filename in &conf.files {
         //check if Ctrl-C has been received. If yes, stop iterating
         if rx.try_recv().is_ok() {
-            return tx.send(true).map_err(|_| {
-                Error::new(ErrorKind::Other, "Could not send signal to clean up.").into()
-            });
+            return tx
+                .send(true)
+                .map_err(|_| Error::other("Could not send signal to clean up.").into());
         };
         //if it's a directory, stop gif looping because there will probably be more files
         if fs::metadata(filename)?.is_dir() {
@@ -90,9 +90,9 @@ fn view_directory(conf: &Config, dirname: &str, (tx, rx): TxRx) -> ViuResult {
     for dir_entry_result in fs::read_dir(dirname)? {
         //check if Ctrl-C has been received. If yes, stop iterating
         if rx.try_recv().is_ok() {
-            return tx.send(true).map_err(|_| {
-                Error::new(ErrorKind::Other, "Could not send signal to clean up.").into()
-            });
+            return tx
+                .send(true)
+                .map_err(|_| Error::other("Could not send signal to clean up.").into());
         };
         let dir_entry = dir_entry_result?;
 
@@ -140,6 +140,9 @@ fn view_file(conf: &Config, filename: &str, (tx, rx): TxRx) -> ViuResult {
             viuer::print_from_file(filename, &conf.viuer_config)?;
         }
     }
+    if conf.caption {
+        println!("{}", filename);
+    }
 
     Ok(())
 }
@@ -191,9 +194,9 @@ where
             //if ctrlc is received then respond so the handler can clear the
             // terminal from leftover colors
             if rx.try_recv().is_ok() {
-                return tx.send(true).map_err(|_| {
-                    Error::new(ErrorKind::Other, "Could not send signal to clean up.").into()
-                });
+                return tx
+                    .send(true)
+                    .map_err(|_| Error::other("Could not send signal to clean up.").into());
             };
 
             //keep replacing old pixels as the gif goes on so that scrollback
